@@ -43,7 +43,7 @@
 -- handled properly, so long as both are given.  If the street type is
 -- omitted, the street names included type will be parsed as the street type.
 --
--- The output is currently a colon seperated list of values:
+-- The output is currently a colon separated list of values:
 -- InternalAddress:StreetAddress:DirectionPrefix:StreetName:StreetType:
 -- DirectionSuffix:Location:State:ZipCode
 -- This returns each element as entered.  It's mainly meant for debugging.
@@ -97,6 +97,9 @@ BEGIN
   -- the input string.
   addressString := substring(rawInput from E'^([0-9].*?)[ ,/.]');
 
+  -- try to pull full street number including non-digits like 1R
+  result.address_alphanumeric := substring(rawInput from E'^([0-9a-zA-Z].*?)[ ,/.]');
+
   IF debug_flag THEN
     raise notice '% addressString: %', clock_timestamp(), addressString;
   END IF;
@@ -112,6 +115,11 @@ BEGIN
                 substring(rawInput from ws || '([0-9]{2,5})$'),
                 substring(rawInput from ws || '([0-9]{6,14})$'));
 
+    result.zip4 := COALESCE(substring(rawInput from ws || '[0-9]{5}-([0-9]{0,4})$'),substring(rawInput from ws || '[0-9]{5}([0-9]{0,4})$'));
+
+    IF debug_flag THEN
+        raise notice '% zip4: %', clock_timestamp(), result.zip4;
+    END IF;
      -- Check if all we got was a zipcode, of either form
     IF zipString IS NULL THEN
       zipString := substring(rawInput from '^([0-9]{5})$');
@@ -434,11 +442,10 @@ BEGIN
 		  END IF;
 		END IF;
 
-
 		IF debug_flag THEN
 			raise notice '% reduced street: %', clock_timestamp(), reducedStreet;
 		END IF;
-		
+
 		-- The pre direction should be at the beginning of the fullStreet string.
 		-- The post direction should be at the beginning of the location string
 		-- if there is no internal address
@@ -603,7 +610,7 @@ BEGIN
         -- a two word direction. eg extracting "East" from "North East"
         -- We do this by sorting by length, and taking the last direction
         -- in the results that is not included in an earlier one.
-        -- This wont be a problem it preDir is North East and postDir is
+        -- This won't be a problem it preDir is North East and postDir is
         -- East as the regex requires a space before the direction.  Only
         -- the East will return from the preDir.
         tempInt := 0;
