@@ -74,7 +74,7 @@ static void test_lwgeom_make_valid(void)
 	lwgeom_free(gin);
 
 	/* We're really only interested in avoiding memory problems.
-   * Convertion to ewkt ensures full scan of coordinates thus
+   * Conversion to ewkt ensures full scan of coordinates thus
    * triggering the error, if any
    */
 	ewkt = lwgeom_to_ewkt(gout);
@@ -98,10 +98,10 @@ static void test_lwgeom_make_valid(void)
 	 TODO: This doesn't work on windows returns in different order.
 	 strk figure out why. For now will replace with normalized version
 	*/
-/*	CU_ASSERT_STRING_EQUAL(ewkt,
+/*	ASSERT_STRING_EQUAL(ewkt,
 "GEOMETRYCOLLECTION(POINT(0 0),MULTIPOLYGON(((5 5,0 0,0 10,5 5)),((5 5,10 10,10 0,5 5))),LINESTRING(10 0,10 10))");*/
 	gexp = lwgeom_from_wkt(
-"GEOMETRYCOLLECTION(POINT(0 0),MULTIPOLYGON(((5 5,0 0,0 10,5 5)),((5 5,10 10,10 0,5 5))),LINESTRING(10 0,10 10))",
+"GEOMETRYCOLLECTION(MULTIPOLYGON(((5 5,10 10,10 0,5 5)),((0 0,0 10,5 5,0 0))),LINESTRING(10 0,10 10),POINT(0 0))",
 		LW_PARSER_CHECK_NONE);
 	check_geom_equal(gout, gexp);
 	lwfree(ewkt);
@@ -122,7 +122,7 @@ static void test_lwgeom_make_valid(void)
 
 	ewkt = lwgeom_to_ewkt(gout);
 	/* printf("c = %s\n", ewkt); */
-	CU_ASSERT_STRING_EQUAL(ewkt,
+	ASSERT_STRING_EQUAL(ewkt,
 "MULTIPOINT(0 0,1 1,2 2)");
 	lwfree(ewkt);
 
@@ -141,12 +141,30 @@ static void test_lwgeom_make_valid(void)
 
 	ewkt = lwgeom_to_ewkt(gout);
 	/* printf("c = %s\n", ewkt); */
-	CU_ASSERT_STRING_EQUAL(ewkt,
+	ASSERT_STRING_EQUAL(ewkt,
 "POLYGON((10 22,10 32,20 32,20 22,10 22))");
 	lwfree(ewkt);
 
 	lwgeom_free(gout);
 	lwgeom_free(gin);
+
+	/* Test collection with empty component */
+
+	gin = lwgeom_from_hexwkb( "0106000020110F000000000000",
+		LW_PARSER_CHECK_NONE);
+	CU_ASSERT(gin != NULL);
+
+	gout = lwgeom_make_valid(gin);
+	CU_ASSERT(gout != NULL);
+
+	ewkt = lwgeom_to_ewkt(gout);
+	/* printf("c = %s\n", ewkt); */
+	ASSERT_STRING_EQUAL(ewkt, "SRID=3857;MULTIPOLYGON EMPTY");
+	lwfree(ewkt);
+
+	lwgeom_free(gout);
+	lwgeom_free(gin);
+
 }
 
 /* TODO: add more tests ! */
