@@ -251,6 +251,7 @@ void decode_geohash_bbox(char *geohash, double *lat, double *lon, int precision)
 */
 int p4d_same(const POINT4D *p1, const POINT4D *p2);
 int p3d_same(const POINT3D *p1, const POINT3D *p2);
+int p3dz_same(const POINT3DZ *p1, const POINT3DZ *p2);
 int p2d_same(const POINT2D *p1, const POINT2D *p2);
 
 /*
@@ -424,6 +425,7 @@ int lwline_is_closed(const LWLINE *line);
 int lwpoly_is_closed(const LWPOLY *poly);
 int lwcircstring_is_closed(const LWCIRCSTRING *curve);
 int lwcompound_is_closed(const LWCOMPOUND *curve);
+int lwcompound_is_valid(const LWCOMPOUND *curve);
 int lwpsurface_is_closed(const LWPSURFACE *psurface);
 int lwtin_is_closed(const LWTIN *tin);
 
@@ -500,5 +502,6 @@ int gbox_contains_point2d(const GBOX *g, const POINT2D *p);
 int lwpoly_contains_point(const LWPOLY *poly, const POINT2D *pt);
 POINT4D* lwmpoint_extract_points_4d(const LWMPOINT* g, uint32_t* npoints, int* input_empty);
 char* lwstrdup(const char* a);
+void* lwalloc0(size_t sz);
 
 #endif /* _LIBLWGEOM_INTERNAL_H */
