@@ -244,7 +244,7 @@ ptarray_append_ptarray(POINTARRAY *pa1, POINTARRAY *pa2, double gap_tolerance)
 	}
 
 	memcpy(getPoint_internal(pa1, pa1->npoints),
-	       getPoint_internal(pa2, poff), ptsize * npoints);
+	       getPoint_internal(pa2, poff), (size_t)ptsize * npoints);
 
 	pa1->npoints = ncap;
 
@@ -538,7 +538,7 @@ ptarray_addPoint(const POINTARRAY *pa, uint8_t *p, size_t pdims, uint32_t where)
 
 	if ( pdims < 2 || pdims > 4 )
 	{
-		lwerror("ptarray_addPoint: point dimension out of range (%d)",
+		lwerror("ptarray_addPoint: point dimension out of range (%zu)",
 		        pdims);
 		return NULL;
 	}
@@ -586,20 +586,8 @@ ptarray_removePoint(POINTARRAY *pa, uint32_t which)
 
 	LWDEBUGF(3, "pa %x which %d", pa, which);
 
-#if PARANOIA_LEVEL > 0
-	if ( which > pa->npoints-1 )
-	{
-		lwerror("%s [%d] offset (%d) out of range (%d..%d)", __FILE__, __LINE__,
-		        which, 0, pa->npoints-1);
-		return NULL;
-	}
-
-	if ( pa->npoints < 3 )
-	{
-		lwerror("%s [%d] can't remove a point from a 2-vertex POINTARRAY", __FILE__, __LINE__);
-		return NULL;
-	}
-#endif
+	assert(which <= pa->npoints-1);
+	assert(pa->npoints >= 3);
 
 	ret = ptarray_construct(FLAGS_GET_Z(pa->flags),
 	                        FLAGS_GET_M(pa->flags), pa->npoints-1);
@@ -753,27 +741,35 @@ ptarray_is_closed_z(const POINTARRAY *in)
 		return ptarray_is_closed_2d(in);
 }
 
+/**
+ * The following is based on the "Fast Winding Number Inclusion of a Point
+ * in a Polygon" algorithm by Dan Sunday.
+ * http://softsurfer.com/Archive/algorithm_0103/algorithm_0103.htm#Winding%20Number
+ *
+ * Return:
+ *  - LW_INSIDE (1) if the point is inside the POINTARRAY
+ *  - LW_BOUNDARY (0) if it is on the boundary.
+ *  - LW_OUTSIDE (-1) if it is outside
+ */
 int
-ptarray_contains_point_partial(const POINTARRAY *pa, const POINT2D *pt, int check_closed, int *winding_number)
+ptarray_contains_point(const POINTARRAY *pa, const POINT2D *pt)
 {
+	const POINT2D *seg1, *seg2;
 	int wn = 0;
-	uint32_t i;
-	double side;
-	const POINT2D *seg1;
-	const POINT2D *seg2;
-	double ymin, ymax;
 
 	seg1 = getPoint2d_cp(pa, 0);
 	seg2 = getPoint2d_cp(pa, pa->npoints-1);
-	if ( check_closed && ! p2d_same(seg1, seg2) )
+	if (!p2d_same(seg1, seg2))
 		lwerror("ptarray_contains_point called on unclosed ring");
 
-	for ( i=1; i < pa->npoints; i++ )
+	for (uint32_t i = 1; i < pa->npoints; i++)
 	{
+		double side, ymin, ymax;
+
 		seg2 = getPoint2d_cp(pa, i);
 
 		/* Zero length segments are ignored. */
-		if ( seg1->x == seg2->x && seg1->y == seg2->y )
+		if (p2d_same(seg1, seg2))
 		{
 			seg1 = seg2;
 			continue;
@@ -1030,32 +1026,27 @@ ptarrayarc_raycast_intersections(const POINTARRAY *pa, const POINT2D *p, int *on
  * The following is based on the "Fast Winding Number Inclusion of a Point
  * in a Polygon" algorithm by Dan Sunday.
  * http://softsurfer.com/Archive/algorithm_0103/algorithm_0103.htm#Winding%20Number
- *
- * Return:
- *  - LW_INSIDE (1) if the point is inside the POINTARRAY
- *  - LW_BOUNDARY (0) if it is on the boundary.
- *  - LW_OUTSIDE (-1) if it is outside
  */
 int
-ptarray_contains_point(const POINTARRAY *pa, const POINT2D *pt)
+ptarray_contains_point_partial(const POINTARRAY *pa, const POINT2D *pt, int check_closed, int *winding_number)
 {
-	const POINT2D *seg1, *seg2;
 	int wn = 0;
+	uint32_t i;
+	double side;
+	const POINT2D *seg1, *seg2;
+	double ymin, ymax;
 
 	seg1 = getPoint2d_cp(pa, 0);
 	seg2 = getPoint2d_cp(pa, pa->npoints-1);
-
-	if (!p2d_same(seg1, seg2))
+	if ( check_closed && ! p2d_same(seg1, seg2) )
 		lwerror("ptarray_contains_point called on unclosed ring");
 
-	for (uint32_t i = 1; i < pa->npoints; i++)
+	for ( i=1; i < pa->npoints; i++ )
 	{
-		double side, ymin, ymax;
-
 		seg2 = getPoint2d_cp(pa, i);
 
 		/* Zero length segments are ignored. */
-		if (p2d_same(seg1, seg2))
+		if ( seg1->x == seg2->x && seg1->y == seg2->y )
 		{
 			seg1 = seg2;
 			continue;
@@ -1105,7 +1096,18 @@ ptarray_contains_point(const POINTARRAY *pa, const POINT2D *pt)
 		seg1 = seg2;
 	}
 
-	return (wn == 0) ? LW_OUTSIDE : LW_INSIDE;
+	/* Sent out the winding number for calls that are building on this as a primitive */
+	if ( winding_number )
+		*winding_number = wn;
+
+	/* Outside */
+	if (wn == 0)
+	{
+		return LW_OUTSIDE;
+	}
+
+	/* Inside */
+	return LW_INSIDE;
 }
 
 /**
@@ -1732,7 +1734,7 @@ ptarray_remove_repeated_points_in_place(POINTARRAY *pa, double tolerance, uint32
 
 /* Out of the points in pa [itfist .. itlast], finds the one that's farthest away from
  * the segment determined by pts[itfist] and pts[itlast].
- * Returns itfirst if no point was found futher away than max_distance_sqr
+ * Returns itfirst if no point was found further away than max_distance_sqr
  */
 static uint32_t
 ptarray_dp_findsplit_in_place(const POINTARRAY *pts, uint32_t it_first, uint32_t it_last, double max_distance_sqr)
@@ -2355,12 +2357,12 @@ ptarray_scroll_in_place(POINTARRAY *pa, const POINT4D *pt)
 	/* TODO: reduce allocations */
 	tmp = ptarray_construct(FLAGS_GET_Z(pa->flags), FLAGS_GET_M(pa->flags), pa->npoints);
 
-	bzero(getPoint_internal(tmp, 0), ptsize * pa->npoints);
+	memset(getPoint_internal(tmp, 0), 0,  (size_t)ptsize * pa->npoints);
 	/* Copy the block from found point to last point into the output array */
 	memcpy(
 		getPoint_internal(tmp, 0),
 		getPoint_internal(pa, it),
-		ptsize * ( pa->npoints - it )
+		(size_t)ptsize * ( pa->npoints - it )
 	);
 
 	/* Copy the block from second point to the found point into the last portion of the
@@ -2368,14 +2370,14 @@ ptarray_scroll_in_place(POINTARRAY *pa, const POINT4D *pt)
 	memcpy(
 		getPoint_internal(tmp, pa->npoints - it),
 		getPoint_internal(pa, 1),
-		ptsize * ( it )
+		(size_t)ptsize * ( it )
 	);
 
 	/* Copy the resulting pointarray back to source one */
 	memcpy(
 		getPoint_internal(pa, 0),
 		getPoint_internal(tmp, 0),
-		ptsize * ( pa->npoints )
+		(size_t)ptsize * ( pa->npoints )
 	);
 
 	ptarray_free(tmp);
