@@ -61,7 +61,7 @@ extern postgisConstants *POSTGIS_CONSTANTS;
 
 /* Infer the install location of postgis, and thus the namespace to use
  * when looking up the type name, and cache oids */
-void postgis_initialize_cache();
+void postgis_initialize_cache(void);
 
 /* Useful if postgis_initialize_cache() has been called before.
  * Otherwise it tries to do a bare lookup */
@@ -71,7 +71,7 @@ Oid postgis_oid(postgisType typ);
  * Note that it's length can be up to strlen(schema) + "." + strlen("spatial_ref_sys") + NULL, i.e: 80 bytes
  * Only useful if postgis_initialize_cache has been called before. Otherwise returns "spatial_ref_sys"
  */
-const char *postgis_spatial_ref_sys();
+const char *postgis_spatial_ref_sys(void);
 
 /****************************************************************************************/
 
@@ -261,9 +261,9 @@ Datum LWGEOM_getBBOX(PG_FUNCTION_ARGS);
 Datum LWGEOM_addBBOX(PG_FUNCTION_ARGS);
 Datum LWGEOM_dropBBOX(PG_FUNCTION_ARGS);
 
-void lwpgerror(const char *fmt, ...);
-void lwpgnotice(const char *fmt, ...);
-void lwpgwarning(const char *fmt, ...);
+void lwpgerror(const char *fmt, ...) __attribute (( format(printf, 1, 2) ));
+void lwpgnotice(const char *fmt, ...) __attribute (( format(printf, 1, 2) ));
+void lwpgwarning(const char *fmt, ...) __attribute (( format(printf, 1, 2) ));
 
 Datum CallerFInfoFunctionCall3(PGFunction func, FmgrInfo *flinfo, Oid collation, Datum arg1, Datum arg2, Datum arg3);
 
