@@ -28,6 +28,8 @@
  */
 
 #include <postgres.h>
+#include <fmgr.h>
+#include <funcapi.h> /* for SRF */
 #include <utils/builtins.h> /* for text_to_cstring() */
 #include <access/htup_details.h> /* for heap_form_tuple() */
 #include <utils/lsyscache.h> /* for get_typlenbyvalalign */
@@ -580,8 +582,7 @@ Datum RASTER_Contour(PG_FUNCTION_ARGS)
 
 		/* No-op on bad return */
 		if (rv == FALSE) {
-			funcctx = SRF_PERCALL_SETUP();
-			SRF_RETURN_DONE(funcctx);
+			PG_RETURN_NULL();
 		}
 
 		funcctx->user_fctx = result;
@@ -718,7 +719,7 @@ Datum RASTER_InterpolateRaster(PG_FUNCTION_ARGS)
 	in_band_height = rt_band_get_height(in_band);
 	in_band_pixtype = rt_band_get_pixtype(in_band);
 	in_band_gdaltype = rt_util_pixtype_to_gdal_datatype(in_band_pixtype);
-	in_band_gdaltype_size = GDALGetDataTypeSize(in_band_gdaltype) / 8;
+	in_band_gdaltype_size = GDALGetDataTypeSizeBytes(in_band_gdaltype);
 
 	/* Quickly copy options struct into local memory context, so we */
 	/* don't have malloc'ed memory lying around */
